@@ -1,5 +1,3 @@
-import six
-
 from sevenbridges.meta.resource import Resource
 from sevenbridges.meta.fields import CompoundField
 from sevenbridges.models.compound.error import Error
@@ -10,7 +8,7 @@ class BulkRecord(Resource):
     resource = CompoundField(cls=Resource)
 
     def __str__(self):
-        return six.text_type('<BulkRecord>')
+        return f'<BulkRecord valid={self.valid}>'
 
     @property
     def valid(self):
@@ -23,9 +21,7 @@ class BulkRecord(Resource):
         data = response.json()
         for item in data.get('items', []):
             record = cls(api=api)
-            if 'error' in item:
-                record._set('error', item['error'])
-            if 'resource' in item:
-                record._set('resource', item['resource'])
+            record._set('error', item.get('error'))
+            record._set('resource', item.get('resource'))
             records.append(record)
         return records
