@@ -1,7 +1,6 @@
 import re
 import logging
 
-import six
 
 from sevenbridges.errors import SbgError, ReadOnlyPropertyError
 from sevenbridges.meta.comp_mutable_dict import CompoundMutableDict
@@ -20,7 +19,7 @@ class Logs(CompoundMutableDict, Resource):
     _name = 'logs'
 
     def __init__(self, **kwargs):
-        super(Logs, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     def __getitem__(self, item):
         try:
@@ -30,13 +29,11 @@ class Logs(CompoundMutableDict, Resource):
                 file_id = match.groups()[0]
                 return File(id=file_id, api=self._api)
             else:
-                raise SbgError('Unable to fetch {} log file!'.format(item))
+                raise SbgError(f'Unable to fetch {item} log file!')
         except Exception as e:
             logger.debug(
-                'Failed to retrieve log file due to an error: %s',
-                six.text_type(e)
+                'Failed to retrieve log file due to an error: %s', str(e)
             )
-            return None
 
     def __setitem__(self, key, value):
         raise ReadOnlyPropertyError('Can not modify read only properties.')
