@@ -1,5 +1,3 @@
-import six
-
 from sevenbridges.meta.resource import Resource
 
 
@@ -15,10 +13,10 @@ class BatchBy(Resource, dict):
         self.parent = kwargs.pop('_parent')
         self.api = kwargs.pop('api')
         for k, v in kwargs.items():
-            super(BatchBy, self).__setitem__(k, v)
+            super().__setitem__(k, v)
 
     def __setitem__(self, key, value):
-        super(BatchBy, self).__setitem__(key, value)
+        super().__setitem__(key, value)
         self.parent._data[self._name][key] = value
         if self._name not in self.parent._dirty:
             self.parent._dirty.update({self._name: {}})
@@ -34,7 +32,7 @@ class BatchBy(Resource, dict):
         values = {}
         for k, _ in self.items():
             values[k] = self[k]
-        return six.text_type(values)
+        return str(values)
 
     __str__ = __repr__
 
@@ -49,9 +47,7 @@ class BatchBy(Resource, dict):
                 self[k] = other[k]
 
     def equals(self, other):
-        if not hasattr(other, '__class__'):
-            return False
-        if not self.__class__ == other.__class__:
+        if not type(other) == type(self):
             return False
         return (
             self is other or
